@@ -1,8 +1,15 @@
 /*
- * $Id: drv_type.c,v 1.2 1996/01/18 14:21:39 jim Exp $
+ * $Id: drv_type.c,v 1.4 1997/10/14 07:33:22 jim Exp $
  * Get CDROM drive type
  *
  * $Log: drv_type.c,v $
+ * Revision 1.4  1997/10/14 07:33:22  jim
+ * can specify device.  Output stuff to stderr
+ *
+ * Revision 1.3  1996/06/04 23:02:28  jim
+ * Patch from Hans Werner Strube (strube@physik3.gwdg.de)
+ * to open volmgt device if normal open fails.
+ *
  * Revision 1.2  1996/01/18 14:21:39  jim
  * Fixing a casting warning
  *
@@ -18,7 +25,7 @@
  */
 
 void
-get_drv_type(int fd)
+get_drv_type(int fd, char *device)
 {
   struct uscsi_cmd cmd;
   unsigned char cdb[12];
@@ -26,7 +33,14 @@ get_drv_type(int fd)
   char vendor[STR_LEN], model[STR_LEN], rev[STR_LEN];
     
   /* open the device */
-  fd = open("/dev/rdsk/c0t6d0s2", 0);
+  if(device != NULL)
+    fd = open(device, 0);
+  else {
+    fd = open("/dev/rdsk/c0t6d0s2", 0);
+    if(fd < 0)
+      fd = open("/vol/dev/aliases/cdrom0", 0);
+  }
+  
   if(fd < 0)
     pop_error(ERR_FILE, "Open of CD-ROM device failed");
 
@@ -59,9 +73,9 @@ get_drv_type(int fd)
   
   /* print out the info */
 
-  printf("Vendor: %s\n", vendor);
-  printf(" Model: %s\n", model);
-  printf("  rev.: %s\n", rev);
+  fprintf(stderr, "Vendor: %s\n", vendor);
+  fprintf(stderr, " Model: %s\n", model);
+  fprintf(stderr, "  rev.: %s\n", rev);
 }
 
  
